@@ -26,7 +26,7 @@ class PythonSwitchNodeBuilder(PythonBaseNodeBuilder):
             nested_graph_builders=self.nested_graphs,
             input_node_ids=self.input_node_ids,
             output_node_ids=self.output_node_id,
-            reload_on_ticked=self.reload_on_ticked
+            reload_on_ticked=self.reload_on_ticked,
         )
 
         return self._build_inputs_and_outputs(node)
